## User

A user in the system.

Field | Type | Description | Required | Default
--- | --- | --- | --- | ---
id | `int` | Unique identifier for the user | Yes | `PydanticUndefined`
username | `str` | User's login name | Yes | `PydanticUndefined`
email | `str` | User's email address | Yes | `PydanticUndefined`
full_name | `Optional[str]` | User's full name | Yes | `-`
age | `Optional[int]` | User's age in years | Yes | `-`
tags | `List[str]` | List of user tags | Yes | `list()`
car | `Optional[Car]` | User's car details | Yes | `-`

## Car

Details about a car.

Field | Type | Description | Required | Default
--- | --- | --- | --- | ---
make | `str` | The manufacturer of the car | Yes | `PydanticUndefined`
price | `int` | The price of the car in dollars | Yes | `PydanticUndefined`